==> deepin-system-monitor-debug-6.0.21-4.1-x86_64_v4.pkg.tar.zst: usr/src/debug/deepin-system-monitor/deepin-system-monitor/deepin-system-monitor-daemon/qrc_deepin-system-monitor-daemon.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.16
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/deepin-system-monitor/deepin-system-monitor-daemon/assets/resources/settings.json
  0x0,0x0,0x1,0x84,
  0x0,
  0x0,0x8,0x5b,0x78,0x9c,0xcd,0x95,0xcb,0x6a,0xc3,0x30,0x10,0x45,0xf7,0xfe,0xa,
  0x61,0x28,0xa4,0xd0,0x45,0xba,0x6c,0xb7,0x5d,0xb7,0x4,0x4a,0xe9,0xa2,0x4,0xa3,
  0xda,0x13,0x5b,0x44,0xf,0x23,0x8d,0xeb,0x9a,0x90,0x7f,0xaf,0xa4,0xc4,0x9,0xf5,
  0x23,0x51,0x1a,0xc,0xf5,0xca,0xd6,0xcc,0x9d,0xb9,0x3a,0xb2,0x3d,0x9b,0x88,0xd8,
  0x2b,0xce,0xb5,0xaa,0x4a,0x13,0x3f,0x92,0xf,0xff,0xec,0xae,0xcd,0xe1,0xce,0x67,
  0xac,0xa1,0xb1,0xe1,0xd8,0x0,0x22,0x93,0x79,0x7c,0xf7,0x3b,0x2a,0xa9,0x0,0x17,
  0x7e,0xdd,0x85,0x4d,0x37,0x3e,0x50,0x7f,0xb8,0x4f,0xaf,0x5f,0x63,0x10,0x44,0xa9,
  0x15,0x42,0x8a,0x4c,0xc9,0x4e,0xe1,0xbe,0x1,0x9f,0x4f,0x16,0x67,0x5,0xaa,0x74,
  0xd1,0x61,0x4b,0xa7,0xad,0x75,0x2d,0x52,0x4e,0xb5,0x48,0x4c,0xcd,0x30,0x2d,0x46,
  0xba,0xf5,0x6d,0x16,0xaa,0x26,0x35,0xd5,0xd2,0xc1,0x22,0x75,0x1,0x92,0x60,0x1,
  0xa4,0x32,0x34,0x7,0x2,0xdf,0x29,0x40,0x66,0xfc,0xa,0x16,0x1a,0x4c,0xa1,0x78,
  0xd6,0x45,0xda,0x2b,0x8d,0x4d,0xe9,0x4b,0x1f,0x59,0x85,0x59,0xca,0x60,0x45,0x2b,
  0x8e,0x56,0xba,0xa2,0xdc,0xc0,0x68,0xf2,0x76,0xbc,0xce,0x25,0x9c,0xd2,0xb2,0x4a,
  0xfc,0x36,0x43,0x51,0x3d,0x2d,0xde,0x5a,0x52,0x47,0x1a,0x64,0x76,0x73,0x1b,0xa,
  0xc4,0x76,0xf4,0xad,0x53,0xcd,0x90,0xa5,0x94,0x87,0x3,0x79,0x98,0x4f,0x4d,0x43,
  0x80,0x50,0xba,0xb9,0xc,0xc8,0xb3,0xd7,0x5c,0xc7,0xc4,0xf6,0xfd,0xb7,0x4c,0x98,
  0x44,0xd0,0x5f,0xe7,0x3d,0xb5,0x3c,0xde,0xf7,0x20,0x5a,0x1d,0x99,0x9,0x26,0x83,
  0x49,0xb4,0xaa,0x3f,0xe2,0xb8,0x9f,0x1c,0x7,0xa7,0x6,0x13,0x64,0x22,0xf8,0xfd,
  0x30,0xa8,0x34,0x10,0x2f,0x26,0x4e,0x4c,0x42,0xc4,0x2d,0xe,0x2f,0x73,0xaa,0x10,
  0xd1,0x11,0xc3,0xfc,0x4c,0x66,0xc1,0x32,0x57,0x1e,0x75,0x75,0xe2,0x7,0x33,0x18,
  0x59,0xf6,0x56,0x7,0xb8,0x9e,0x9e,0x21,0x2,0x8c,0xc9,0xe9,0xd8,0x6e,0xe,0xdc,
  0x5e,0x14,0xb2,0x95,0x3d,0xfd,0xdd,0x5c,0x98,0x7c,0x6c,0x38,0x57,0xf6,0xab,0x4f,
  0x86,0x27,0xea,0x55,0x2e,0xf,0xa2,0xf6,0x54,0xf7,0x3d,0x38,0x93,0xeb,0xcf,0xa,
  0xd1,0x4e,0xc5,0xeb,0x4f,0x21,0x1a,0x8e,0xef,0xd6,0x97,0xd1,0x36,0xfa,0x1,0xeb,
  0xe5,0xb7,0x94,
  
};

static const unsigned char qt_resource_name[] = {
  // resources
  0x0,0x9,
  0xa,0x6c,0x78,0x43,
  0x0,0x72,
  0x0,0x65,0x0,0x73,0x0,0x6f,0x0,0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,0x73,
    // settings.json
  0x0,0xd,
  0xd,0xf2,0x7b,0x3e,
  0x0,0x73,
  0x0,0x65,0x0,0x74,0x0,0x74,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x73,0x0,0x2e,0x0,0x6a,0x0,0x73,0x0,0x6f,0x0,0x6e,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x93,0x5d,0xc5,0xf6,0x38,
  // :/resources
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x93,0x5d,0xc5,0xf6,0x38,
  // :/resources/settings.json
  0x0,0x0,0x0,0x18,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x93,0x5d,0xc5,0xf6,0x38,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZlib()
{
    extern const unsigned char qt_resourceFeatureZlib;
    return qt_resourceFeatureZlib;
}
#else
unsigned char qResourceFeatureZlib();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_deepin_system_monitor_daemon)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_deepin_system_monitor_daemon)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_deepin_system_monitor_daemon)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_deepin_system_monitor_daemon)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZlib());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_deepin_system_monitor_daemon)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_deepin_system_monitor_daemon)(); }
   } dummy;
}

==> deepin-system-monitor-debug-6.0.22-2.1-x86_64_v4.pkg.tar.zst: usr/src/debug/deepin-system-monitor/deepin-system-monitor/deepin-system-monitor-daemon/qrc_deepin-system-monitor-daemon.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.16
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/deepin-system-monitor/deepin-system-monitor-daemon/assets/resources/settings.json
  0x0,0x0,0x1,0x84,
  0x0,
  0x0,0x8,0x5b,0x78,0x9c,0xcd,0x95,0xcb,0x6a,0xc3,0x30,0x10,0x45,0xf7,0xfe,0xa,
  0x61,0x28,0xa4,0xd0,0x45,0xba,0x6c,0xb7,0x5d,0xb7,0x4,0x4a,0xe9,0xa2,0x4,0xa3,
  0xda,0x13,0x5b,0x44,0xf,0x23,0x8d,0xeb,0x9a,0x90,0x7f,0xaf,0xa4,0xc4,0x9,0xf5,
  0x23,0x51,0x1a,0xc,0xf5,0xca,0xd6,0xcc,0x9d,0xb9,0x3a,0xb2,0x3d,0x9b,0x88,0xd8,
  0x2b,0xce,0xb5,0xaa,0x4a,0x13,0x3f,0x92,0xf,0xff,0xec,0xae,0xcd,0xe1,0xce,0x67,
  0xac,0xa1,0xb1,0xe1,0xd8,0x0,0x22,0x93,0x79,0x7c,0xf7,0x3b,0x2a,0xa9,0x0,0x17,
  0x7e,0xdd,0x85,0x4d,0x37,0x3e,0x50,0x7f,0xb8,0x4f,0xaf,0x5f,0x63,0x10,0x44,0xa9,
  0x15,0x42,0x8a,0x4c,0xc9,0x4e,0xe1,0xbe,0x1,0x9f,0x4f,0x16,0x67,0x5,0xaa,0x74,
  0xd1,0x61,0x4b,0xa7,0xad,0x75,0x2d,0x52,0x4e,0xb5,0x48,0x4c,0xcd,0x30,0x2d,0x46,
  0xba,0xf5,0x6d,0x16,0xaa,0x26,0x35,0xd5,0xd2,0xc1,0x22,0x75,0x1,0x92,0x60,0x1,
  0xa4,0x32,0x34,0x7,0x2,0xdf,0x29,0x40,0x66,0xfc,0xa,0x16,0x1a,0x4c,0xa1,0x78,
  0xd6,0x45,0xda,0x2b,0x8d,0x4d,0xe9,0x4b,0x1f,0x59,0x85,0x59,0xca,0x60,0x45,0x2b,
  0x8e,0x56,0xba,0xa2,0xdc,0xc0,0x68,0xf2,0x76,0xbc,0xce,0x25,0x9c,0xd2,0xb2,0x4a,
  0xfc,0x36,0x43,0x51,0x3d,0x2d,0xde,0x5a,0x52,0x47,0x1a,0x64,0x76,0x73,0x1b,0xa,
  0xc4,0x76,0xf4,0xad,0x53,0xcd,0x90,0xa5,0x94,0x87,0x3,0x79,0x98,0x4f,0x4d,0x43,
  0x80,0x50,0xba,0xb9,0xc,0xc8,0xb3,0xd7,0x5c,0xc7,0xc4,0xf6,0xfd,0xb7,0x4c,0x98,
  0x44,0xd0,0x5f,0xe7,0x3d,0xb5,0x3c,0xde,0xf7,0x20,0x5a,0x1d,0x99,0x9,0x26,0x83,
  0x49,0xb4,0xaa,0x3f,0xe2,0xb8,0x9f,0x1c,0x7,0xa7,0x6,0x13,0x64,0x22,0xf8,0xfd,
  0x30,0xa8,0x34,0x10,0x2f,0x26,0x4e,0x4c,0x42,0xc4,0x2d,0xe,0x2f,0x73,0xaa,0x10,
  0xd1,0x11,0xc3,0xfc,0x4c,0x66,0xc1,0x32,0x57,0x1e,0x75,0x75,0xe2,0x7,0x33,0x18,
  0x59,0xf6,0x56,0x7,0xb8,0x9e,0x9e,0x21,0x2,0x8c,0xc9,0xe9,0xd8,0x6e,0xe,0xdc,
  0x5e,0x14,0xb2,0x95,0x3d,0xfd,0xdd,0x5c,0x98,0x7c,0x6c,0x38,0x57,0xf6,0xab,0x4f,
  0x86,0x27,0xea,0x55,0x2e,0xf,0xa2,0xf6,0x54,0xf7,0x3d,0x38,0x93,0xeb,0xcf,0xa,
  0xd1,0x4e,0xc5,0xeb,0x4f,0x21,0x1a,0x8e,0xef,0xd6,0x97,0xd1,0x36,0xfa,0x1,0xeb,
  0xe5,0xb7,0x94,
  
};

static const unsigned char qt_resource_name[] = {
  // resources
  0x0,0x9,
  0xa,0x6c,0x78,0x43,
  0x0,0x72,
  0x0,0x65,0x0,0x73,0x0,0x6f,0x0,0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,0x73,
    // settings.json
  0x0,0xd,
  0xd,0xf2,0x7b,0x3e,
  0x0,0x73,
  0x0,0x65,0x0,0x74,0x0,0x74,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x73,0x0,0x2e,0x0,0x6a,0x0,0x73,0x0,0x6f,0x0,0x6e,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x95,0x26,0xe0,0xa7,0x60,
  // :/resources
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x95,0x26,0xe0,0xa7,0x60,
  // :/resources/settings.json
  0x0,0x0,0x0,0x18,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x95,0x26,0xe0,0xa7,0x60,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZlib()
{
    extern const unsigned char qt_resourceFeatureZlib;
    return qt_resourceFeatureZlib;
}
#else
unsigned char qResourceFeatureZlib();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_deepin_system_monitor_daemon)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_deepin_system_monitor_daemon)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_deepin_system_monitor_daemon)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_deepin_system_monitor_daemon)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZlib());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_deepin_system_monitor_daemon)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_deepin_system_monitor_daemon)(); }
   } dummy;
}
